==> okteta-0.25.5.tar.xz: okteta-0.25.5/kasten/controllers/view/charsetconversion/charsetconversiontoolfactory.h <==
/*
    This file is part of the Okteta Kasten module, made within the KDE community.

    Copyright 2011 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef CHARSETCONVERSIONTOOLFACTORY_H
#define CHARSETCONVERSIONTOOLFACTORY_H

// lib
#include <kasten/okteta/oktetakastencontrollers_export.h>
// Kasten core
#include <kasten/abstracttoolfactory.h>

namespace Kasten {

class OKTETAKASTENCONTROLLERS_EXPORT CharsetConversionToolFactory : public AbstractToolFactory
{
public:
    CharsetConversionToolFactory();
    ~CharsetConversionToolFactory() override;

public: // AbstractToolFactory API
    AbstractTool* create() override;
};

}

#endif

==> okteta_4.13.3.orig.tar.xz: okteta-4.13.3/kasten/controllers/view/charsetconversion/charsetconversiontoolfactory.h <==
/*
    This file is part of the Okteta Kasten module, made within the KDE community.

    Copyright 2011 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef CHARSETCONVERSIONTOOLFACTORY_H
#define CHARSETCONVERSIONTOOLFACTORY_H

// lib
#include "oktetakastencontrollers_export.h"
// Kasten core
#include <abstracttoolfactory.h>


namespace Kasten2
{

class OKTETAKASTENCONTROLLERS_EXPORT CharsetConversionToolFactory : public AbstractToolFactory
{
  public:
    CharsetConversionToolFactory();
    virtual ~CharsetConversionToolFactory();

  public: // AbstractToolFactory API
    virtual AbstractTool* create();
};

}

#endif
